Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(526)

Unified Diff: appengine/swarming/server/task_request.py

Issue 2984773002: Change task timeout limit to 3 days (Closed)
Patch Set: fix error message Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | appengine/swarming/server/task_request_test.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: appengine/swarming/server/task_request.py
diff --git a/appengine/swarming/server/task_request.py b/appengine/swarming/server/task_request.py
index 063fc2645531e0582db07c00d31f2dcc2e577fdb..944b0d1b857e11866bd9b0853c5b2633b3c8e07e 100644
--- a/appengine/swarming/server/task_request.py
+++ b/appengine/swarming/server/task_request.py
@@ -75,8 +75,8 @@ import cipd
MAXIMUM_PRIORITY = 255
-# One day in seconds. Add 10s to account for small jitter.
-_ONE_DAY_SECS = 24*60*60 + 10
+# Three days in seconds. Add 10s to account for small jitter.
+_THREE_DAY_SECS = 3*24*60*60 + 10
# Seven day in seconds. Add 10s to account for small jitter.
@@ -227,10 +227,10 @@ def _validate_task_run_id(_prop, value):
def _validate_timeout(prop, value):
"""Validates timeouts in seconds in TaskProperties."""
- if value and not (_MIN_TIMEOUT_SECS <= value <= _ONE_DAY_SECS):
+ if value and not (_MIN_TIMEOUT_SECS <= value <= _THREE_DAY_SECS):
# pylint: disable=W0212
raise datastore_errors.BadValueError(
- '%s (%ds) must be 0 or between %ds and one day' %
+ '%s (%ds) must be 0 or between %ds and three days' %
(prop._name, value, _MIN_TIMEOUT_SECS))
« no previous file with comments | « no previous file | appengine/swarming/server/task_request_test.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698